@@ -9,31 +9,22 @@ import discord
 import logging
 import asyncio
 import royalnet.engineer as engi
-import royalnet.engineer.wrench as w
 
 from . import bullets
-from .royaltyping import MsgChannel
 
 log = logging.getLogger(__name__)
 
 
 class DiscordPDA(discord.AutoShardedClient):
     def __init__(self, *args, **kwargs):
-        log.debug(f"Creating new DiscordPDA")
+        log.debug(f"Creating new DiscordPDA...")
 
-        intents: discord.Intents
-        if intents := kwargs.get("intents"):
-            log.debug(f"Captured intents, force-enabling them")
-            intents.guild_messages = True
-            intents.dm_messages = True
-        else:
-            log.debug(f"No intents passed, manually selecting them")
-            intents = discord.Intents.default()
-            intents.guild_messages = True
-            intents.dm_messages = True
+        log.debug(f"Subscribing to guild_messages and dm_messages by setting intents...")
+        intents = discord.Intents(guild_messages=True, dm_messages=True)
 
+        log.debug(f"Initializing AutoShardedClient...")
         super().__init__(*args, intents=intents, **kwargs)
-        self.dispensers: t.Dict[bullets.DiscordChannel, engi.Dispenser] = {}
+        self.dispensers: t.Dict[int, engi.Dispenser] = {}
         """
         A :class:`dict` which maps :class:`bullets.DiscordChannel`s to :class:`royalnet.engineer.dispenser.Dispenser`s.
         """
@@ -61,7 +52,9 @@ class DiscordPDA(discord.AutoShardedClient):
         log.info(f"Shard #{shard_id} resumed connection")
 
     async def on_error(self, event_method, *args, **kwargs):
-        # TODO: we might want to change this behaviour
+        """
+        .. todo:: Maybe the behaviour of re-raising errors should be changed...
+        """
         raise
 
     async def on_message(self, message: discord.Message):
@@ -101,15 +94,21 @@ class DiscordPDA(discord.AutoShardedClient):
         :param bullet: The bullet to put in the dispenser.
         """
         log.debug(f"Finding dispenser for channel: {channel}")
-        dispenser = self.dispensers.get(channel)
+        dispenser = self.dispensers.get(hash(channel))
         if not dispenser:
             log.debug(f"Dispenser not found, creating one")
             dispenser = engi.Dispenser()
-            self.dispensers[channel] = dispenser
+            self.dispensers[hash(channel)] = dispenser
 
+        log.debug("Getting running loop...")
         loop = asyncio.get_running_loop()
+
         for conversation in self.conversations:
+            log.debug(f"Creating run task for: {conversation}")
             loop.create_task(dispenser.run(conversation), name=f"{repr(conversation)}")
 
-        log.debug(f"Putting message bullet in the dispenser: {bullet}")
+        log.debug("Running a event loop cycle...")
+        await asyncio.sleep(0)
+
+        log.debug(f"Putting bullet in dispenser: {bullet}")
         await dispenser.put(bullet)
